aboutsummaryrefslogtreecommitdiffstats
path: root/src/gaudio/driver_play.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gaudio/driver_play.h')
-rw-r--r--src/gaudio/driver_play.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/gaudio/driver_play.h b/src/gaudio/driver_play.h
index 72ad4747..343a0fed 100644
--- a/src/gaudio/driver_play.h
+++ b/src/gaudio/driver_play.h
@@ -42,19 +42,19 @@ extern "C" {
* @iclass
* @notapi
*/
-GAudioData *gaudioPlayGetDataBlockI(void);
+GDataBuffer *gaudioPlayGetDataBlockI(void);
/**
* @brief Release a block of audio data to the free list
*
* @param[in] paud The GAudioData block to be released.
*
* @note Defined in the high level GAUDIO code for use by the GAUDIO play drivers.
*
* @iclass
* @notapi
*/
-void gaudioPlayReleaseDataBlockI(GAudioData *paud);
+void gaudioPlayReleaseDataBlockI(GDataBuffer *paud);
/**
* @brief Signal that all playing has now stopped
@@ -107,7 +107,7 @@ void gaudio_play_lld_stop(void);
* @brief Set the output volume.
* @return TRUE if successful.
*
- * @param[in] 0->255 (0 = muted)
+ * @param[in] vol 0->255 (0 = muted)
*
* @note Some drivers may not support this. They will return FALSE.
* @note For stereo devices, both channels are set to the same volume.
@@ -42,19 +42,19 @@ extern "C" {
* @brief Release a block of audio data to the free list
*
- * @param[in] paud The GAudioData block to be released.
+ * @param[in] paud The GDataBuffer block to be released.
*
* @note Defined in the high level GAUDIO code for use by the GAUDIO play drivers.